@@ -9,14 +9,15 @@ class DiscoveryChannel:
         self.name = name
 
     @classmethod
-    def search(cls):
+    def search(cls, lang='ca'):
         """
         Return a list with all the discovery
         channels allowed in Odoo.
 
         :return: List of discovery channels
         """
-        response_data = Client().get("{}".format(cls._url_path))
+        headers = {'Accept-Language': lang}
+        response_data = Client().get("{}".format(cls._url_path), extra_headers=headers)
 
         discovery_channels = []
         for dc in response_data.get("discovery_channels"):
