@@ -23,10 +23,12 @@ class ProductCatalog:
         self.products = [Product(**product) for product in products]
 
     @classmethod
-    def search(cls, code="", category=""):
+    def search(cls, code="", category="", lang="ca"):
+        headers = {'Accept-Language': lang}
         response_data = Client().get(
             "{}".format(cls._url_path),
             params={"code": code, "categ": category},
+            extra_headers=headers
         )
 
         pricelists = []
