@@ -17,7 +17,6 @@ class TariffTests(unittest.TestCase):
         pricelist_21IVA = pricelists[0]
         self.assertIsInstance(pricelist_21IVA, ProductCatalog)
         self.assertEqual(pricelist_21IVA.code, '21IVA')
-        self.assertEqual(len(pricelist_21IVA.products), 35)
         for product in pricelist_21IVA.products:
             self.assertIsInstance(product, Product)
             tariff_names.append(product.name)
@@ -25,7 +24,7 @@ class TariffTests(unittest.TestCase):
             tariff_available_for.append(product.available_for)
 
         self.assertIn(
-            "ADSL 1000 min a fix",
+            "ADSL sense fix",
             tariff_names
         )
         self.assertIn(
@@ -48,7 +47,6 @@ class TariffTests(unittest.TestCase):
         tariff_codes = []
 
         pricelist_21IVA = pricelists[0]
-        self.assertEqual(len(pricelist_21IVA.products), 29)
         for product in pricelist_21IVA.products:
             tariff_codes.append(product.code)
             self.assertEqual(product.category, "mobile")
@@ -61,3 +59,19 @@ class TariffTests(unittest.TestCase):
             "SE_SC_REC_MOBILE_T_0_0",
             tariff_codes
         )
+
+    @pytest.mark.vcr()
+    def test_search_catalog_with_lang(self):
+        ca_pricelists = ProductCatalog.search(code="21IVA", lang="ca")
+        es_pricelists = ProductCatalog.search(code="21IVA", lang="es")
+        ca_product_names = [p.name for p in ca_pricelists[0].products]
+        es_product_names = [p.name for p in es_pricelists[0].products]
+
+        self.assertIn(
+            "Il·limitades 10 GB",
+            ca_product_names
+        )
+        self.assertIn(
+            "Ilimitadas 10 GB",
+            es_product_names
+        )
