@@ -299,3 +299,25 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
         ).to_dict()
 
         self.assertEqual(len(sr_data["lead_line_ids"]), 2)
+
+    def test_mobile_contract_new_sc_icc(self):
+        expected_icc = "12345"
+
+        contract_data = FakeContractForm().data
+
+        contract_data["service"] = "mobile"
+        contract_data["mobile_option"] = "new"
+        contract_data["mobile_delivery_street"] = None
+        contract_data["mobile_sc_icc"] = expected_icc
+
+        subscription_request_id = 123
+
+        sr_data = CRMLeadFromContractForm(
+            contract_data,
+            {},
+            subscription_request_id=subscription_request_id,
+        ).to_dict()
+        lead_line = sr_data["lead_line_ids"][0]
+        mobile_isp_info = lead_line["mobile_isp_info"]
+
+        self.assertEqual(mobile_isp_info["icc"], expected_icc)
